@@ -8,7 +8,8 @@ from django.core.mail import send_mail
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
 from django.db import models
-from django_nopassword.utils import User
+
+from django_nopassword.utils import User, get_username
 
 
 class LoginCode(models.Model):
@@ -27,15 +28,24 @@ class LoginCode(models.Model):
         super(LoginCode, self).save(*args, **kwargs)
         send_mail(
             'Login code',
-            'Login with this url http://%s%s?next=%s' % (
-                getattr(settings, 'SERVER_URL', 'example.com'),
-                reverse('django_nopassword.views.login_with_code', args=[self.user.username, self.code]),
-                self.next
-            ),
+            'Login with this url %s' % self.login_url(),
             getattr(settings, 'SERVER_EMAIL', 'root@example.com'),
             [self.user.email],
         )
 
+    def login_url(self):
+        username = get_username(self.user)
+        if getattr(settings, 'NOPASSWORD_HIDE_USERNAME', False):
+            view = reverse('django_nopassword.views.login_with_code', args=[self.code]),
+        else:
+            view = reverse('django_nopassword.views.login_with_code_and_username', args=[username, self.code]),
+
+        return 'http://%s%s?next=%s' % (
+            getattr(settings, 'SERVER_URL', 'example.com'),
+            view,
+            self.next
+        )
+
     @classmethod
     def create_code_for_user(cls, user, next=None):
         if not user.is_active:
